/*
 *  Name        : kclock.cpp
 *  Version     : 0.5.1
 *  Description : A clock with some more...
 *
 *  Copyright (C) 1998 Luca Montecchiani <m.luca@usa.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include "kclock.h"
#include "kclock.moc"

Kclock::Kclock( QWidget *parent, const char *name )
	: QWidget( parent, name )
{
	initMetaObject();

	// start internal timer
	time = QTime::currentTime();
	QTimer *internalTimer = new QTimer( this );
	connect( internalTimer, SIGNAL(timeout()), SLOT(Timeout()) );
	// internalTimer->start( 1000 );
	internalTimer->start( 100 );

	// define the menu
	menu      = new QPopupMenu();
	menu1     = new QPopupMenu();
	menu2     = new QPopupMenu();
	dateID    = menu->insertItem(klocale->translate("Show date"), this, SLOT(Show_date()));
	secondID  = menu->insertItem(klocale->translate("Show seconds"), this, SLOT(Show_second()));
	ontopID   = menu->insertItem(klocale->translate("Always on top"), this, SLOT(Show_ontop()));
	digitalID = menu->insertItem(klocale->translate("Digital display"), this, SLOT(Show_digital()));
	beepID    = menu->insertItem(klocale->translate("Beep every hour"), this, SLOT(Beep()));
	tree_dID  = menu->insertItem(klocale->translate("3D effect"), this, SLOT(Show_tree_d()));
	borderID  = menu->insertItem(klocale->translate("Show border"), this, SLOT(Show_border()));

	menu->insertItem(klocale->translate("Font..."), menu1);
	menu1->insertItem(klocale->translate("Digital Font"), this, SLOT(selectFont()));
	menu1->insertSeparator();
	menu1->insertItem(klocale->translate("Reset Font"), this, SLOT(ResetFont()));

	menu->insertItem(klocale->translate("Colors..."), menu2);
	menu2->insertItem(klocale->translate("Background"), this, SLOT(selectBack()));
	menu2->insertItem(klocale->translate("Foreground"), this, SLOT(selectFore()));
	menu2->insertItem(klocale->translate("Shadow"), this, SLOT(selectShad()));
	menu2->insertSeparator();
	menu2->insertItem(klocale->translate("Reset Colors"), this, SLOT(resetCol()));

	menu->insertSeparator();
	menu->insertItem(klocale->translate("Set system Date/Time"), this, SLOT(Set_time()));
	menu->insertSeparator();
	menu->insertItem(klocale->translate("Save setting"), this, SLOT(Save_config()));
	menu->insertItem(klocale->translate("Help"), this, SLOT(Help()));
	menu->insertItem(klocale->translate("About"), this, SLOT(About()));
	menu->insertSeparator();
	menu->insertItem(klocale->translate("Exit"), this, SLOT(Quit()));
	menu->setCheckable( TRUE );

	// reading rc file
	onmenu = FALSE;

	KConfig	*config = kapp->getConfig();

	config->setGroup("Geometry");
	setGeometry( config->readNumEntry("TopLevelGeometry-x", 0), config->readNumEntry("TopLevelGeometry-y", 0), config->readNumEntry("TopLevelGeometry-w", 100), config->readNumEntry("TopLevelGeometry-h", 100) );

	config->setGroup("Option");
	date 	= !config->readNumEntry("date", FALSE);
	second 	= !config->readNumEntry("second", TRUE);
	digital = !config->readNumEntry("digital", FALSE);
	ontop 	= !config->readNumEntry("ontop", FALSE);
	beep 	= !config->readNumEntry("beep", FALSE);
	tree_d 	= !config->readNumEntry("tree_d", TRUE);
	border 	= !config->readNumEntry("border", TRUE);
	ver 	= config->readNumEntry("ver", 0);
	config->writeEntry("ver", VER);

	config->setGroup( "Font" );
	font.setFamily(config->readEntry( "Family", "Utopia"));
	font.setPointSize(config->readNumEntry( "Point Size", 51));
	font.setWeight(config->readNumEntry( "Weight", 75));
	font.setItalic(config->readNumEntry( "Italic",TRUE ));
	font.setBold(config->readNumEntry( "Bold",TRUE ));

	config->setGroup( "Color" );
	QColor colortmp = lightGray;
	Back = config->readColorEntry( "Background" , &colortmp );
	colortmp = black;
	Fore = config->readColorEntry( "Foreground" , &colortmp );
	colortmp = gray;
	Shad = config->readColorEntry( "Shadow" , &colortmp );

	setBackgroundColor(Back);

	if ( ver != VER ) Hints();

	// settings up some things
	Show_ontop();
	Show_digital();
	Show_second();
	Show_date();
	Beep();
	Show_tree_d();
	Show_border();
}

Kclock::~Kclock()
{
}

void Kclock::resetCol()
{
	Back = lightGray;
	Fore = black;
	Shad = gray;
	setBackgroundColor(Back);
	Initialize();
}

void Kclock::selectBack()
{
	onmenu = TRUE;
	KColorDialog::getColor(Back);
	setBackgroundColor(Back);
	onmenu = FALSE;
	Initialize();
}

void Kclock::selectFore()
{
	onmenu = TRUE;
	KColorDialog::getColor(Fore);
	onmenu = FALSE;
	Initialize();
}

void Kclock::selectShad()
{
	onmenu = TRUE;
	KColorDialog::getColor(Shad);
	onmenu = FALSE;
	Initialize();
}

void Kclock::selectFont()
{
	onmenu = TRUE;
	KFontDialog::getFont(font);
	onmenu = FALSE;
}

void Kclock::ResetFont()
{
	onmenu = TRUE;
        font.setFamily("Utopia");
        font.setPointSize(51);
        font.setWeight(75);
        font.setItalic(TRUE);
        font.setBold(TRUE);     
	onmenu = FALSE;
}

void Kclock::Timeout()
{
	// check if saver is running !!!
	if ( (ontop) && (!hasFocus()) && (!menu->isVisible()) && (!onmenu) ) raise();
	repaint();
}

void Kclock::Save_config()
{
	KConfig *config = kapp->getConfig();

	config->setGroup("Option");
	config->writeEntry("second",second);
	config->writeEntry("date",date);
	config->writeEntry("digital",digital);
	config->writeEntry("ontop",ontop);
	config->writeEntry("beep",beep);
	config->writeEntry("tree_d",tree_d);
	config->writeEntry("border",border);

	config->setGroup("Geometry");
	config->writeEntry("TopLevelGeometry-x",x());
	config->writeEntry("TopLevelGeometry-y",y());
	config->writeEntry("TopLevelGeometry-w",width());
	config->writeEntry("TopLevelGeometry-h",height());

	config->setGroup( "Font" );
	config->writeEntry( "Family",font.family());
	config->writeEntry( "Point Size",font.pointSize());
	config->writeEntry( "Weight",font.weight());
	config->writeEntry( "Italic",font.italic());
	config->writeEntry( "Bold",font.bold());

	config->setGroup( "Color" );
	config->writeEntry( "Background" , Back );
	config->writeEntry( "Foreground" , Fore );
	config->writeEntry( "Shadow" , Shad );
}

void Kclock::Show_tree_d()
{
	tree_d = !tree_d;
	menu->setItemChecked( tree_dID, tree_d );
}

void Kclock::Beep()
{
	beep = !beep;
	menu->setItemChecked( beepID, beep );
}

void Kclock::Show_second()
{
	second = !second;
	menu->setItemChecked( secondID, second );
}

void Kclock::Show_ontop()
{
	ontop = !ontop;
	menu->setItemChecked( ontopID, ontop );
  	setFocusPolicy( QWidget::StrongFocus );
}

void Kclock::Show_digital()
{
	digital = !digital;
	menu->setItemChecked( digitalID, digital );
}

void Kclock::Quit()
{
	delete menu;
	delete menu1;
	delete menu2;
	kapp->quit();   
}

void Kclock::Set_time()
{
	onmenu = TRUE;
	ConfigDlg *conf = new ConfigDlg(0,"configdlg",TRUE);
	conf->show();
	delete conf;
	if ( date )
		{
		QDate d = QDate::currentDate();
		setCaption(d.toString());
		}
	onmenu = FALSE;
}

void Kclock::Help()
{
	kapp->invokeHTMLHelp("kclock/kclock.html","");
}                                                        

void Kclock::Hints()
{
	onmenu = TRUE;
	QMessageBox::about( 0, "Welcome to kclock 0.5.1 !", 
	klocale->translate( "Mouse buttons actions:\n\n"\
	"Left : move the window when kclock is in no-border mode\n\n"\
	"Mid : copy Date/Time on the clipboard\n\n"\
	"Right : show kclock menu"));
	onmenu = FALSE;
}                                                        

void Kclock::About()
{
	onmenu = TRUE;
	QMessageBox::about( 0, "About kclock 0.5.1",
	"Kclock 0.5.1\n\n"\
	"(C) 1998 Luca Montecchiani (m.luca@usa.net)\n\n"\
	"http://www.geocities.com/SiliconValley/Vista/2964/");
	onmenu = FALSE;
}

void Kclock::Show_border()
{
	border = !border;
	menu->setItemChecked( borderID, border );
	if ( border )
		recreate(parentWidget(),0,pos(),TRUE);
	else 	recreate(parentWidget(),WStyle_Customize | WStyle_NoBorder | WState_ClickToFocus, pos(), TRUE);
	Initialize();
}

void Kclock::Initialize()
{
	// Get icon !!
	QPixmap p1( kclock_xpm );
	setIcon(p1);

	// flicker free code by Remi Guyomarch <rguyom@mail.dotcom.fr>
	setBackgroundMode(NoBackground);

	// very sensible !!
	setFocusPolicy( QWidget::StrongFocus );
}

void Kclock::Show_date()
{
	date = !date;
	menu->setItemChecked( dateID, date );
	if ( date )
		{
		QDate d = QDate::currentDate();
		setCaption(d.toString());
		}
	else	setCaption("kclock");
}

void Kclock::mousePressEvent(QMouseEvent *event)
{
	if ( event->button() == LeftButton )
		raise();
	if ( event->button() == RightButton )
		menu->popup(mapToGlobal(event->pos()));
	if ( event->button() == MidButton )
		{
		QString s = QDate::currentDate().toString() + "\n" + QTime::currentTime().toString();
		QClipboard *cb = QApplication::clipboard();
		cb->setText( s );
		QMessageBox::information( 0, "kclock",klocale->translate("Date/Time copied on the clipboard."));
		}
}

void Kclock::mouseMoveEvent(QMouseEvent *event)
{
	if ( !border )
		move(mapToGlobal(event->pos()));
}

void Kclock::paintEvent( QPaintEvent * )
{
	time = QTime::currentTime();
	if ( ( time.minute() == 0 ) && ( time.second() == 0 ) && beep )
		kapp->beep();

	if ( !isVisible() )
		return;

	// flicker free code by Remi Guyomarch <rguyom@mail.dotcom.fr>
	// QPainter paint;
	// paint.begin( this );
	QPixmap pm( size() );
	QPainter paint;
	// pm.fill( backgroundColor() );
	pm.fill( Back );
	paint.begin( &pm );

	if ( !border )
		{
		paint.drawRect(0,0,width(),height());
		}

	if ( digital )
		{
		QString s = QTime::currentTime().toString();
		if ( s[0] == '0' )
			s[0] = '0';

		if ( !second )
			{
			s[5] = '\0';
			font.setPointSize(QMIN((int)(width()/3),height()));
			}
		else 	font.setPointSize(QMIN((int)(width()/4.7),height()));

		paint.setFont( font );
		if ( tree_d )
			{
			paint.setPen( Shad );
			paint.drawText(3,3,width(),height(),AlignHCenter|AlignVCenter,s,-1,0,0);
			}
		paint.setPen( Fore );
		paint.drawText(rect(),AlignHCenter|AlignVCenter,s,-1,0,0);
		}
	else 	{
		QPointArray pts;
		QPoint cp = rect().center();
		int d = QMIN(width(),height());
		if ( tree_d )
			{
			paint.setPen( Shad );
			paint.setBrush( Shad );
			paint.setViewport(4,4,width(),height());
			}
		else 	{
			paint.setPen( Fore );
			paint.setBrush( Fore );
			}

		for ( int c=0 ; c < 2 ; c++ )
			{
			QWMatrix matrix;
			matrix.translate( cp.x(), cp.y() );
			matrix.scale( d/1000.0F, d/1000.0F );

			// lancetta delle ore 
			float h_angle = 30*(time.hour()%12-3) + time.minute()/2;
			matrix.rotate( h_angle );
			paint.setWorldMatrix( matrix );
			pts.setPoints( 4, -20,0,  0,-20, 300,0, 0,20 );
			paint.drawPolygon( pts );
			matrix.rotate( -h_angle );

			// lancetta dei minuti
			float m_angle = (time.minute()-15)*6;
			matrix.rotate( m_angle );
			paint.setWorldMatrix( matrix );
			pts.setPoints( 4, -10,0, 0,-10, 400,0, 0,10 );
			paint.drawPolygon( pts );
			matrix.rotate( -m_angle );

			// lancetta dei secondi
			float s_angle = (time.second()-15)*6;
			matrix.rotate( s_angle );
			paint.setWorldMatrix( matrix );
			pts.setPoints(4,0,0,0,0,400,0,0,0);
			if ( second )
				paint.drawPolygon( pts );
			matrix.rotate( -s_angle );

			// quadrante
			for ( int i=0 ; i < 60 ; i++ )
				{
				paint.setWorldMatrix( matrix );
				if ( (i % 5) == 0 )
					paint.drawLine( 450,0, 500,0 );	// draw hour lines
				else	paint.drawPoint( 480,0 );	// draw second lines
				matrix.rotate( 6 );
				}

			if ( tree_d )
				{
				paint.setPen( Fore );
				paint.setBrush( Fore );
				paint.setViewport(0,0,width(),height());
				}
			else	break;
			}
		}
	paint.end();

	// flicker free code by Remi Guyomarch <rguyom@mail.dotcom.fr>
	bitBlt (this, 0,0, &pm); 
}

void Kclock::focusOutEvent( QFocusEvent * )
{
	if ( (ontop) && (!hasFocus()) && (!menu->isVisible()) && (!onmenu) )
		{
		raise();
		repaint();
		}
}

ConfigDlg:: ConfigDlg( QWidget * parent, const char * name, bool modal )
	: QTabDialog( parent, name, modal )
{
	initMetaObject();

	QTime t = QTime::currentTime();
	QDate d = QDate::currentDate();
	QString Buf;

// get saved GMT value
	KConfig *config = kapp->getConfig();
	config->setGroup("Option");
	GMT 	= config->readNumEntry("GMT", 12);

	setCaption( klocale->translate("Properties - Date/Time") );
	setMinimumSize( 392,308 );
	setMaximumSize( 392,308 );
	setFixedSize( 392,308 );

	setOKButton(ktr("&Close"));
	if ( !modal )
		connect( this, SIGNAL(applyButtonPressed()), SLOT(Quit()) );

// create first TAB
	QWidget *tzone = new QWidget(this,klocale->translate("Time Zone") );
	QPixmap pm(kapp->kdedir()+"/share/apps/kclock/pics/kclock_world.xpm");
	QLabel *logo = new QLabel(tzone);
	logo->setPixmap(pm);
	logo->setGeometry(10, 42, pm.width(), pm.height());

	QComboBox *edCombo = new QComboBox( FALSE, tzone);
	for ( int i=12 ; i > 0 ; i-- )
		{
		QString s;
		s.sprintf( "GMT -%d", i);
		edCombo->insertItem( s );
		}
	edCombo->insertItem( "GMT 0" );
	for ( int i=1 ; i < 13 ; i++ )
		{
		QString s;
		s.sprintf( "GMT +%d", i);
		edCombo->insertItem( s );
		}
	edCombo->setGeometry(10, 10, pm.width(), pm.height());
	edCombo->setFixedHeight(edCombo->sizeHint().height());
	edCombo->setStyle(WindowsStyle);
	edCombo->setCurrentItem( GMT );
	connect( edCombo, SIGNAL(activated(int)), SLOT(Set_GMT(int)) );

// create second TAB
	QWidget *tdate = new QWidget(this,"Date/Time" );
	QLabel* tmpQLabel;
	tmpQLabel = new QLabel( tdate, "Label_9" );
	tmpQLabel->setGeometry( 10, 80, 355, 10 );
	tmpQLabel->setFrameStyle( 20 );
	tmpQLabel->setAlignment( 289 );
	tmpQLabel->setMargin( -1 );

	hour = new QLineEdit( tdate, "LineEdit_hour" );
	hour->setGeometry( 10, 35, 25, 24 );
	Buf.sprintf("%02d",t.hour());
	hour->setText( Buf );
	hour->setMaxLength( 2 );
	hour->setEchoMode( QLineEdit::Normal );
	hour->setFrame( TRUE );

	minute = new QLineEdit( tdate, "LineEdit_minute" );
	minute->setGeometry( 40, 35, 25, 24 );
	Buf.sprintf("%02d",t.minute());
	minute->setText( Buf );
	minute->setMaxLength( 2 );
	minute->setEchoMode( QLineEdit::Normal );
	minute->setFrame( TRUE );

	second = new QLineEdit( tdate, "LineEdit_second" );
	second->setGeometry( 70, 35, 25, 24 );
	Buf.sprintf("%02d",t.second());
	second->setText( Buf );
	second->setMaxLength( 2 );
	second->setEchoMode( QLineEdit::Normal );
	second->setFrame( TRUE );

	day = new QLineEdit( tdate, "LineEdit_day" );
	day->setGeometry( 160, 35, 25, 24 );
	Buf.sprintf("%02d",d.day());
	day->setText( Buf );
	day->setMaxLength( 2 );
	day->setEchoMode( QLineEdit::Normal );
	day->setFrame( TRUE );

	month = new QComboBox( FALSE, tdate, "ComboBox_month" );
	month->setGeometry( 190, 35, 52, 24 );
   	month->setSizeLimit( 12 );
	month->setAutoResize( FALSE );
	month->setStyle(WindowsStyle);
	month->insertItem( klocale->translate("Jan") );
	month->insertItem( klocale->translate("Feb") );
	month->insertItem( klocale->translate("Mar") );
	month->insertItem( klocale->translate("Apr") );
	month->insertItem( klocale->translate("May") );
	month->insertItem( klocale->translate("Jun") );
	month->insertItem( klocale->translate("Jul") );
	month->insertItem( klocale->translate("Aug") );
	month->insertItem( klocale->translate("Sep") );
	month->insertItem( klocale->translate("Oct") );
	month->insertItem( klocale->translate("Nov") );
	month->insertItem( klocale->translate("Dec") );
	month->setCurrentItem(d.month()-1);

	year = new QLineEdit( tdate, "LineEdit_year" );
	year->setGeometry( 245, 35, 38, 24 );
	Buf.sprintf("%04d",d.year());
	year->setText( Buf );
	year->setMaxLength( 4 );
	year->setEchoMode( QLineEdit::Normal );
	year->setFrame( TRUE );

	QPushButton* tmpQPushButton;
	tmpQPushButton = new QPushButton( tdate, "PushButton_5" );
	tmpQPushButton->setGeometry( 96, 35, 20, 12 );
	connect( tmpQPushButton, SIGNAL(pressed()), SLOT(Inc_time()) );
	tmpQPushButton->setText( "+" );
	tmpQPushButton->setAutoRepeat( FALSE );
	tmpQPushButton->setAutoResize( FALSE );

	tmpQPushButton = new QPushButton( tdate, "PushButton_6" );
	tmpQPushButton->setGeometry( 96, 47, 20, 12 );
	connect( tmpQPushButton, SIGNAL(pressed()), SLOT(Dec_time()) );
	tmpQPushButton->setText( "-" );
	tmpQPushButton->setAutoRepeat( FALSE );
	tmpQPushButton->setAutoResize( FALSE );

	tmpQLabel = new QLabel( tdate, "Label_5" );
	tmpQLabel->setGeometry( 10, 15, 35, 15 );
	tmpQLabel->setText( klocale->translate("Time:") );
	tmpQLabel->setAlignment( 289 );
	tmpQLabel->setMargin( -1 );

	tmpQLabel = new QLabel( tdate, "Label_6" );
	tmpQLabel->setGeometry( 160, 15, 35, 15 );
	tmpQLabel->setText( klocale->translate("Date:") );
	tmpQLabel->setAlignment( 289 );
	tmpQLabel->setMargin( -1 );

	tmpQPushButton = new QPushButton( tdate, "PushButton_7" );
	tmpQPushButton->setGeometry( 285, 35, 20, 12 );
	connect( tmpQPushButton, SIGNAL(pressed()), SLOT(Inc_date()) );
	tmpQPushButton->setText( "+" );
	tmpQPushButton->setAutoRepeat( FALSE );
	tmpQPushButton->setAutoResize( FALSE );

	tmpQPushButton = new QPushButton( tdate, "PushButton_8" );
	tmpQPushButton->setGeometry( 285, 47, 20, 12 );
	connect( tmpQPushButton, SIGNAL(pressed()), SLOT(Dec_date()) );
	tmpQPushButton->setText( "-" );
	tmpQPushButton->setAutoRepeat( FALSE );
	tmpQPushButton->setAutoResize( FALSE );

        tmpQPushButton = new QPushButton( tdate, "Set" );
        tmpQPushButton->setGeometry( 315, 35, 50, 24 );
        connect( tmpQPushButton, SIGNAL(clicked()), SLOT(Set_dt()) );
        tmpQPushButton->setText( ktr("&Save") );
        tmpQPushButton->setAutoRepeat( FALSE );
        tmpQPushButton->setAutoResize( FALSE );

        tmpQPushButton = new QPushButton( tdate, "SetNet" );
        tmpQPushButton->setGeometry( 10, 100, 160, 24 );
        connect( tmpQPushButton, SIGNAL(clicked()), SLOT(Set_dt_net()) );
        tmpQPushButton->setText( klocale->translate("&Get time from the NET") );
        tmpQPushButton->setAutoRepeat( FALSE );
        tmpQPushButton->setAutoResize( FALSE );

        tdate->setMinimumSize( 375,230 );
        tdate->setMaximumSize( 375,230 );
        tdate->setFixedSize(   375,230 );
        tzone->setMinimumSize( 375,230 );
        tzone->setMaximumSize( 375,230 );
        tzone->setFixedSize(   375,230 );

// finally add it ad master TAB
        addTab(tdate,klocale->translate("Date/Time"));
        addTab(tzone,klocale->translate("Time Zone"));
}

void ConfigDlg::Quit()
{
	delete(this);
	kapp->quit();
}

void ConfigDlg::Set_GMT(int gmt)
{
        GMT = gmt;
        KConfig *config = kapp->getConfig();
        config->setGroup("Option");
        config->writeEntry("GMT",GMT);
}

void ConfigDlg::Inc_time()
{
	if ( hour->hasFocus() )
		Joke(hour,1,0,23);
	if ( minute->hasFocus() )
		Joke(minute,1,0,59);
	if ( second->hasFocus() )
		Joke(second,1,0,59);
}

void ConfigDlg::Dec_time()
{
	if ( hour->hasFocus() )
		Joke(hour,-1,0,23);
	if ( minute->hasFocus() )
		Joke(minute,-1,0,59);
	if ( second->hasFocus() )
		Joke(second,-1,0,59);
}

void ConfigDlg::Inc_date()
{
	if ( day->hasFocus() )
		Joke(day,1,1,31 );
	if ( year->hasFocus() )
		Joke(year,1,0,9999);
	if ( ( month->hasFocus() ) && ( month->currentItem() < 11 ) )
		month->setCurrentItem(month->currentItem()+1);
}

void ConfigDlg::Dec_date()
{
	if ( day->hasFocus() )
		Joke(day,-1,1,31);
	if ( year->hasFocus() )
		Joke(year,-1,0,9999);
	if ( ( month->hasFocus() ) && ( month->currentItem() > 0 ) )
		month->setCurrentItem(month->currentItem()-1);
}

void ConfigDlg::Joke(QLineEdit *edit,int incr,int Min,int Max)
{
	BufI=atoi(edit->text());
	BufI=BufI + incr;
	if ( BufI > Max ) BufI = Min;
	if ( BufI < Min ) BufI = Max;
	if ( Max > 99 )
		BufS.sprintf("%04d",BufI);
	else	BufS.sprintf("%02d",BufI);
	edit->setText(BufS);	
}

void ConfigDlg::Set_dt()
{
	QString Param;
	Param.sprintf("%02d %02d %02d %02d %04d %02d",month->currentItem()+1,atoi(day->text()),atoi(hour->text()),atoi(minute->text()),atoi(year->text()),atoi(second->text()));
	BufS=kapp->kdedir()+"/bin/kclock.sh "+Param;
	int res = system(BufS);
	if ( res != 0 )
		{
		BufS.sprintf("Kclock error #%d",res/256);
		QMessageBox::warning( 0, BufS,klocale->translate("setting new Date/Time !!"));
		}
	else 	QMessageBox::information( 0, "Kclock",klocale->translate("Date/Time succesfully changed"));
}

void ConfigDlg::Set_dt_net()
{
	BufS.sprintf(kapp->kdedir()+"/bin/kclocknet.sh GMT %d",GMT - 12);
	int res = system(BufS);
	if ( res != 0 )
		{
		BufS.sprintf("Kclock error #%d",res/256);
		QMessageBox::warning( 0, BufS,klocale->translate("getting time from the Net !!"));
		}
	else 	QMessageBox::information( 0, "Kclock",klocale->translate("Date/Time succesfully changed"));
		
}

// ***********************************************************************
// |||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
// >>>>>>>>>>>>>>>>>>>>>>>>> Our trip start here <<<<<<<<<<<<<<<<<<<<<<<<<
// |||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
// ***********************************************************************
int main( int argc, char **argv )
{
	KApplication app( argc, argv );
	if ( strcmp(argv[1],"-set") != 0 )
		{
		Kclock *clock = new Kclock;
		app.setMainWidget( clock );
		clock->show();
		}
	else	{
		ConfigDlg *conf = new ConfigDlg(0,"configdlg",FALSE);
		app.setMainWidget( conf );
		conf->show();
		}
	app.exec();
}
