/*
 *  Name        : kclock.h
 *  Version     : 0.5.1
 *  Description : A clock with some more...
 *
 *  Copyright (C) 1998 Luca Montecchiani <m.luca@usa.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef ACLOCK_H
#define ACLOCK_H 

#include <qtimer.h>
#include <qcombo.h>
#include <qtabdlg.h>
#include <qpainter.h>
#include <qmsgbox.h>
#include <qwidget.h>
#include <qdatetm.h>
#include <qpopmenu.h> 
#include <qapp.h>
#include <qpixmap.h>
#include <qlabel.h>
#include <qlined.h>
#include <qpushbt.h>
#include <qclipbrd.h>

#include <kapp.h> 
#include <kfontdialog.h>
#include <kcolordlg.h>
#include <klocale.h>

#include <stdlib.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>

#define VER	51
#define ktr klocale->translate

/* XPM */
static const char *kclock_xpm[]={
"31 32 16 1",
". c #007878",
"# c #006c68",
"a c #104848",
"b c #081c18",
"c c #000000",
"d c #003c38",
"e c #304440",
"f c #d8dcd8",
"g c #888c88",
"h c #080808",
"i c #001818",
"j c #004c48",
"k c #000808",
"l c #002c28",
"m c #005c58",
"n c #f8fcf8",
"................#..............",
"..............#abcd#...........",
"..............defgehij.........",
"..............kehegfgel........",
"............#mbgfgeheeb#.......",
"............iggeheggebk........",
"..........#lcbeggebbeed........",
".........#dbbeebbeggeb#........",
"........dbggfgffgeheggl........",
".......jefffnfnnfffgbcd........",
"......iegfnnnnnfgnnfecl#.......",
".....#bffnnnnnnggnnffgi........",
".....defnnnnnnnbgnnnfge#.......",
".....igfnnffnngefnnnnfem.......",
"....#bffnngbegegfnnnnfgk.......",
".....dgfnnnfgegfnnnnnngd.......",
".....kgfnnnnffggnnnnnngb#......",
".....mefnnnnnnnfnnnnnfecj......",
".....#egfnnnnnnffnnnngeee......",
"......igfnnnnnnfgnnngghe.......",
".....#lcefnnnnnnnnffeeim.......",
"......dcbeggfnnfnfggbj.........",
"......lfgeceegggggebd..........",
"......#beggebbebbbd#...........",
"......deebbeggebcl#............",
"......kbegeeheggi..............",
".....#beecbegehm#..............",
"......lbegebcbk................",
".......jiheegbd................",
".........#dcbd#................",
"............#..................",
"..............................."};

class Kclock : public QWidget
{
	Q_OBJECT
public:
	Kclock( QWidget *parent=0, const char *name=0 );
	~Kclock();

protected:
	void		paintEvent( QPaintEvent * );
	void		mousePressEvent(QMouseEvent *event);
	void		mouseMoveEvent(QMouseEvent *event);
	void		focusOutEvent(QFocusEvent *event);

private slots:
	void		Timeout();
	void		About();
	void		Hints();
	void		Quit();
	void		Show_second();
	void		Show_date();
	void		Show_ontop();
	void		Show_digital();
	void		Show_tree_d();
	void		Save_config();
	void		Set_time();
	void		Help();
	void		Beep();
	void		Show_border();
	void		selectFont();
	void		ResetFont();
	void		selectShad();
	void		selectFore();
	void		selectBack();
	void		resetCol();
	void		Initialize();

private:
	QTime		time;
	QPopupMenu 	*menu;
	QPopupMenu 	*menu1;
	QPopupMenu 	*menu2;
	QFont 		font;
	QColor		Back;
	QColor		Fore;
	QColor		Shad;

	bool		second;
	bool		digital;
	bool		date;
	bool		ontop;
	bool		tree_d;
	bool		beep;
	bool		onmenu;
	bool		border;
	int		ver;

	int		secondID;
	int		digitalID;
	int		dateID;
	int		ontopID;
	int		beepID;
	int		tree_dID;
	int		borderID;
};

class ConfigDlg : public QTabDialog
{
	Q_OBJECT
public:
	ConfigDlg( QWidget * parent=0, const char * name=0, bool modal=FALSE );
	~ConfigDlg() {}

private slots:
	void 		Inc_time();
	void 		Inc_date();
	void 		Dec_time();
	void 		Dec_date();
	void 		Set_dt();
	void 		Set_dt_net();
	void 		Joke(QLineEdit* edit,int incr,int Max,int Min);
	void 		Quit();
	void            Set_GMT(int gmt);

private:
	QLineEdit* 	hour;
	QLineEdit* 	minute;
	QLineEdit* 	second;
	QLineEdit* 	day;
	QComboBox* 	month;
	QLineEdit* 	year;
	QLineEdit* 	setcmd;
	int 		BufI;
	QString		BufS;
	int		GMT;
};

#endif
